@@ -1,6 +1,9 @@
 package Bitcoin::Crypto::Config;
 
-use v5.10; use warnings;
+our $VERSION = "0.996";
+
+use v5.10;
+use warnings;
 use Exporter qw(import);
 
 our @EXPORT = qw(
