@@ -1,14 +1,14 @@
 package Bitcoin::Crypto::Types;
 
-use v5.10; use warnings;
+our $VERSION = "0.996";
+
+use v5.10;
+use warnings;
 use Type::Library -base;
 use Type::Coercion;
 use Types::Common::Numeric qw(assert_PositiveInt);
 use Types::Standard qw(Int InstanceOf);
 use Math::BigInt 1.999808 try => 'LTM,GMP';
-use Bitcoin::Crypto;
-
-our $VERSION = Bitcoin::Crypto->VERSION;
 
 __PACKAGE__->add_type(
 	name => "IntMaxBits",
